/**
  ******************************************************************************
  * @file     ADC_CFG.c
  * @author   sinomcu.com-AE
  * @brief    ADC config
  *    
  *          This file provides functions to ADC config:
  *              ADC IN1(PA1),IN4(PA4),software Trig
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
 */

#include "ADC_CFG.h"

/**
  * @brief  ADC IN1 Pin PA1 Initialization
  * @param  None
  * @retval None
 */
void adc_in_pin_init(void) {
  MS32_GPIO_InitTypeDef GpioInitStruct = {0};

  /* PA1   --> ADC_IN1 */
  /* PA4   --> ADC_IN4 */
  MS32_GPIO_StructInit(&GpioInitStruct);  
  GpioInitStruct.Pin = MS32_GPIO_PIN_1 | MS32_GPIO_PIN_4;
  GpioInitStruct.Mode = MS32_GPIO_MODE_ANALOG;
  GpioInitStruct.Pull = MS32_GPIO_PULL_NO;
  MS32_GPIO_Init(GPIOA, &GpioInitStruct);
}

/**
  * @brief  ADC Initialization Function
  * @param  None
  * @retval None
 */
void adc_init(void) {
  MS32_ADC_InitTypeDef AdcInitStruct = {0};
  MS32_ADC_REG_InitTypeDef AdcRegInitStruct = {0};

  adc_in_pin_init();

  /* from here,configure need ADSTART=0 */ 
  /* ADC must be disabled. */
  MS32_ADC_StructInit(&AdcInitStruct); 
  AdcInitStruct.Clock = MS32_ADC_CLOCK_ASYNC;              /* need ADC close,ADC clk 16M */ 
  AdcInitStruct.Resolution = MS32_ADC_RESOLUTION_12B;      /* 12bit mode*/
  AdcInitStruct.DataAlignment = MS32_ADC_DATA_ALIGN_RIGHT; /* ADC result align right*/
  AdcInitStruct.LowPowerMode = MS32_ADC_LP_MODE_NONE;     
  MS32_ADC_Init(ADC1, &AdcInitStruct);

  MS32_ADC_REG_StructInit(&AdcRegInitStruct);
  AdcRegInitStruct.TriggerSource = MS32_ADC_REG_TRIG_SOFTWARE;            /* software*/
  AdcRegInitStruct.SequencerDiscont = MS32_ADC_REG_SEQ_DISCONT_DISABLE;   
  AdcRegInitStruct.ContinuousMode = MS32_ADC_REG_CONV_SINGLE;
  AdcRegInitStruct.DMATransfer = MS32_ADC_REG_DMA_TRANSFER_LIMITED;
  AdcRegInitStruct.Overrun = MS32_ADC_REG_OVR_DATA_OVERWRITTEN;           /* if OVR,result lasest value*/
  MS32_ADC_REG_Init(ADC1, &AdcRegInitStruct);

  MS32_ADC_SetSamplingTimeCommonChannels(ADC1, MS32_ADC_SAMPLINGTIME_1CYCLE_5);  
  MS32_ADC_REG_SetSequencerChAdd(ADC1, MS32_ADC_CHANNEL_1 | MS32_ADC_CHANNEL_4);
  MS32_ADC_REG_SetSequencerScanDirection(ADC1, MS32_ADC_REG_SEQ_SCAN_DIR_FORWARD);    
}

/******************************** END OF FILE ******************************** */
