/**
  ******************************************************************************
  * @file     DataProcess.c
  * @author   sinomcu.com-AE
  * @brief    RS485 Data Process
  *    
  *          This file provides functions:
  *    Recv_DataAnalysis() RS485 received data analysis and dispse.
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
 */

#include "stdio.h"
#include "ms32f0xx.h"
#include "user_config.h"
#include "UART_user.h"
#include "DataProcess.h"

extern uint16_t ADC_Voltage_buff[];

UartRecvStatus recv_status = WAIT_STAR;
UartRecvFinishFlag recv_finsh = NO_FINISH;
uint8_t RS485_Recv_buff[RS485_DATA_LEN] = {0x00};
uint8_t RS485_Send_buff[RS485_DATA_LEN] = {0x00};

void Recv_DataProcess(void);

/**
  * @brief  RS485 receive data analysis
  * @param  none
  * @retval none
 */
void Recv_DataAnalysis(void) {
  uint8_t address=0;

  if(recv_status == UART_ERROR_ORE) {                      /* uart error interrupt occur */
    recv_status =UART_ERROR_CLR;
    Debug_Log("\r\n--!!!UART ORE Occur!!!");
  }
  else if((recv_status == UART_ERROR_NIOSE)||(recv_status == UART_ERROR_NO_DEF)) {  /* uart error interrupt occur */ 
    recv_status =UART_ERROR_CLR;
    Debug_Log("\r\n--!!!UART ERROR!!!");
    Debug_Log("\r\n--!!!UART RX IRQ Disable!!!");
  }
  else if(recv_finsh == RECV_ERROR) {                      /* frame format not correct */
    recv_finsh =RECV_ERROR_CLR;
    Debug_Log("\r\n--###recv char not the correct frame format");
  }
  else if(recv_finsh == FINISH) {                          /* data accord with frame format */
    recv_finsh = FINISH_CLR;
    /* caculation slave address*/
    address = (RS485_Recv_buff[RS485_DATA_ADD_POS]-0x30)*10 +(RS485_Recv_buff[RS485_DATA_ADD_POS+1]-0x30);
    if(address == SLAVE_ADD) {                             /* address match*/
      Debug_Log("\r\n--Inf:RS485 address match.");
      Recv_DataProcess();                                  /* data dispose*/
    }
  } 
}

/**
  * @brief  RS485 receive data process and send back
  * @param  none
  * @retval none
 */
void Recv_DataProcess(void) {
  FlagStatus need_send_back =RESET;
  uint16_t voltage=0;
  uint8_t count=0;

  switch(RS485_Recv_buff[RS485_DATA_CMD_POS] ) { /* distinguish commond type*/
    case RS485_CMD_TYPE_ANA: /* analog channal data request*/
      if(RS485_Recv_buff[RS485_DATA_CMD_POS+1] ==RS485_CMD_ANA_CH1) {          /* analog channel 1*/
        voltage =ADC_Voltage_buff[0];
        need_send_back =SET;
      }
      else if(RS485_Recv_buff[RS485_DATA_CMD_POS+1] ==RS485_CMD_ANA_CH2) {     /* analog channel 2*/
        voltage =ADC_Voltage_buff[1];
        need_send_back =SET;
      }
      /*analog voltage value uint16_t to string*/
      sprintf((char *)(RS485_Send_buff+RS485_DATA_DATA_POS),":%dmV\r\n",voltage);
      /*send buff frame head:address,commond*/
      for(count=0;count <RS485_DATA_DATA_POS;count++) {
        RS485_Send_buff[count] =RS485_Recv_buff[count];
      }
      break;        
    case RS485_CMD_TYPE_LED:
      break;
    default:
      break;
  }

  if(need_send_back ==SET) {
    need_send_back =RESET;
    Send_buff_Uart(RS485_Send_buff);   /* loop send RS485 data*/
    Debug_Log("\r\n--Inf:RS485 Send Back.");   
  }
}

/******************************** END OF FILE ******************************** */
